@@ -44,9 +44,6 @@
 # include <netinet/tcp.h>
 # include <netdb.h>
 # include <pthread.h>
-# ifdef HAVE_ENDIAN_H
-#  include <endian.h>
-# endif
 #endif /* FAKEROOT_FAKENET */
 #include <fcntl.h>
 #include <unistd.h>
@@ -482,7 +479,7 @@ static void open_comm_sd(void)
     fail("fcntl(F_SETFD, FD_CLOEXEC)");
 
   int val = 1;
-  if (setsockopt(comm_sd, SOL_TCP, TCP_NODELAY, &val, sizeof (val)) < 0)
+  if (setsockopt(comm_sd, IPPROTO_TCP, TCP_NODELAY, &val, sizeof (val)) < 0)
       fail("setsockopt(TCP_NODELAY)");
 
   while (1) {
@@ -516,9 +513,9 @@ void send_fakem(const struct fake_msg *buf)
   if(init_get_msg()!=-1){
     memcpy(&fm.msg, buf, sizeof(*buf));
     fm.mtype=1;
-#if __BYTE_ORDER == __BIG_ENDIAN
+#if BYTE_ORDER == BIG_ENDIAN
     ((struct fake_msg*)&fm.msg)->magic=FAKEROOT_MAGIC_BE;
-#elif __BYTE_ORDER == __LITTLE_ENDIAN
+#elif BYTE_ORDER == LITTLE_ENDIAN
     ((struct fake_msg*)&fm.msg)->magic=FAKEROOT_MAGIC_LE;
 #endif
     do
@@ -595,9 +592,9 @@ void send_get_fakem(struct fake_msg *buf)
         Use swapX here instead of ntoh/hton
         that do nothing on big-endian machines
       */
-#if __BYTE_ORDER == __LITTLE_ENDIAN
+#if BYTE_ORDER == LITTLE_ENDIAN
       if (magic_candidate == FAKEROOT_MAGIC_BE) {
-#elif __BYTE_ORDER == __BIG_ENDIAN
+#elif BYTE_ORDER == BIG_ENDIAN
       if (magic_candidate == FAKEROOT_MAGIC_LE) {
 #endif
          buf->id = bswapl(buf->id);
