@@ -139,10 +139,6 @@
 # define FAKE_KEY port
 #endif /* FAKEROOT_FAKENET */
 
-#ifndef SOL_TCP
-# define SOL_TCP 6 /* this should probably be done with getprotoent */
-#endif
-
 #define fakestat_equal(a, b)  ((a)->dev == (b)->dev && (a)->ino == (b)->ino)
 
 #ifndef FAKEROOT_FAKENET
@@ -794,7 +790,7 @@ void process_chmod(struct fake_msg *buf){
     */
 
     if ((buf->st.mode&S_IFMT) != (st->mode&S_IFMT) &&
-        ((buf->st.mode&S_IFMT) != S_IFREG || (!st->mode&(S_IFBLK|S_IFCHR)))) {
+        ((buf->st.mode&S_IFMT) != S_IFREG || (!(st->mode&(S_IFBLK|S_IFCHR))))) {
       fprintf(stderr,"FAKEROOT: chmod mode=%lo incompatible with "
               "existing mode=%lo\n", (unsigned long)buf->st.mode, (unsigned long)st->mode);
       st->mode = buf->st.mode;
@@ -1483,7 +1479,7 @@ int main(int argc, char **argv){
     fail("setsockopt(SO_REUSEADDR)");
 
   val = 1;
-  if (setsockopt(sd, SOL_TCP, TCP_NODELAY, &val, sizeof (val)) < 0)
+  if (setsockopt(sd, IPPROTO_TCP, TCP_NODELAY, &val, sizeof (val)) < 0)
     fail("setsockopt(TCP_NODELAY)");
 
   if (port > 0) {
